/**
 * PHP bindings to the rrdtool
 *
 * This source file is subject to the BSD license that is bundled
 * with this package in the file LICENSE.
 * ---------------------------------------------------------------
 *  Author: Miroslav Kubelik <koubel@php.net>
 * ---------------------------------------------------------------
 */

#ifndef RRD_CREATE_H
#define RRD_CREATE_H

void rrd_create_minit(TSRMLS_D);
PHP_FUNCTION(rrd_create);

#endif  /* RRD_CREATE_H */
